@@ -237,7 +237,7 @@ class Globals:
         self.updateDependencies()
         self.makeApiAvaliable(self.apiPackage)
         self.makeApisAvaliable(self.apisPath)
-        self.printRootPath(self.localPath)
+        self.spotRootPath(self.localPath)
 
     def makeApiAvaliable(self,apiPackageName) :
         self.apiTree = {}
@@ -261,18 +261,16 @@ class Globals:
             except Exception as exception :
                 self.error(self.__class__,f'Not possible to run makeApisAvaliable({apisPath}) rotine',exception)
 
-
-    def printRootPath(self,rootPath) :
+    def spotRootPath(self,rootPath) :
         if self.printRootPathStatus :
             try :
                 apiPackageList = os.listdir(rootPath)
                 for apiPackage in apiPackageList :
-                    self.rootPath[apiPackage] = self.addNode(f'{rootPath}{apiPackage}')
+                    self.rootPathTree[apiPackage] = self.addNode(f'{rootPath}{apiPackage}')
                 if self.debugStatus :
                     self.printTree(self.rootPathTree,f'{Constant.DEBUG}Root tree (printRootPathStatus is active)')
             except Exception as exception :
-                self.error(self.__class__,f'Not possible to run printRootPath({rootPath}) rotine',exception)
-
+                self.error(self.__class__,f'Not possible to run spotRootPath({rootPath}) rotine',exception)
 
     def giveLocalVisibilityToFrameworkApis(self,apiPackageNameList):
         if apiPackageNameList :
@@ -684,6 +682,9 @@ class Globals:
     def getStaticPackagePath(self) :
         return getStaticPackagePath()
 
+    def searchTreeList(self,search,tree):
+        return searchTreeList(search,tree)
+
     def getEncoding(self, encoding) :
         if encoding :
             return encoding
@@ -743,11 +744,22 @@ def getStaticPackagePath() :
     log.debug(getStaticPackagePath,f'Static packages list: {staticPackageList}. Picking the first one')
     staticPackage = str(staticPackageList[0])
     staticPackage = staticPackage.replace(f'{Globals.BACK_SLASH}{Globals.BACK_SLASH}',Globals.OS_SEPARATOR)
-    staticPackage = staticPackage.replace(Globals.SLASH,Globals.OS_SEPARATOR)
     staticPackage = staticPackage.replace(Globals.BACK_SLASH,Globals.OS_SEPARATOR)
-    staticPackage = f'{staticPackage.split(Globals.PYTHON_LANGUAGE_NAME)[0]}'
-    if not staticPackage[-1] == str(Globals.OS_SEPARATOR) :
-        staticPackage = f'{staticPackage}{Globals.OS_SEPARATOR}'
-    staticPackage = f'{staticPackage}{Globals.PYTHON_LANGUAGE_NAME}{Globals.STATIC_DIRECTORY_PATH}'
+    staticPackage = staticPackage.replace(f'{Globals.SLASH}{Globals.SLASH}',Globals.OS_SEPARATOR)
+    staticPackage = staticPackage.replace(Globals.SLASH,Globals.OS_SEPARATOR)
+    if staticPackage[-1] == str(Globals.OS_SEPARATOR) :
+        staticPackage = staticPackage[:-1]
+    staticPackage = f'{staticPackage}{Globals.STATIC_DIRECTORY_PATH}'
     log.debug(getStaticPackagePath,f'Static package: "{staticPackage}"')
     return staticPackage
+
+def searchTreeList(search,tree) :
+    def keepSearching(search,history,tree,treeList):
+        for key in tree.keys() :
+            newHistory = f'{history}.{key}'
+            if search and search in newHistory :
+                treeList.append(newHistory)
+            keepSearching(search,newHistory,tree[key], treeList)
+    treeList = []
+    keepSearching(search,'root',tree,treeList)
+    return treeList
